/* -*- Mode: C; c-basic-offset: 4 -*- */
/* pygtk - python bindings for GTK+
 * Copyright (C) 1998-1999 James Henstridge <james@daa.com.au>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <Python.h>
#include <gtkhtml/gtkhtml.h>

#include "../pygtk/pygtk.h"
#include "gtkhtml_impl.c"

static PyObject *_wrap_gtk_html_begin (PyObject *self, PyObject *args) {
    gchar *url;
    PyObject *html, *handle;
    GtkHTMLStreamHandle stream;
    
    if (!PyArg_ParseTuple(args, "O!s:gtk_html_begin",
			  &PyGtk_Type, &html, &url))
	return NULL;
    stream = gtk_html_begin (GTK_HTML (PyGtk_Get(html)), url);
    
    handle = PyCObject_FromVoidPtr((void *) stream, NULL);

    if (!handle)
	return NULL;

    return (PyObject *) handle;
}

static PyObject *_wrap_gtk_html_write (PyObject *self, PyObject *args) {
    char *buf;
    int length;
    PyObject *html, *handle;
    GtkHTMLStreamHandle stream;
    
    if (!PyArg_ParseTuple(args, "O!O!s#:gtk_html_write",
			  &PyGtk_Type, &html,
			  &PyCObject_Type, &handle,
			  &buf, &length))
	return NULL;

    stream = (GtkHTMLStreamHandle) PyCObject_AsVoidPtr (handle);
    gtk_html_write (GTK_HTML (PyGtk_Get(html)), stream, buf, length);
    
    Py_INCREF(Py_None);
    return Py_None;
}

static PyObject *_wrap_gtk_html_end (PyObject *self, PyObject *args) {
    char *buf;
    int status;
    PyObject *html, *handle;
    GtkHTMLStreamHandle stream;
    
    if (!PyArg_ParseTuple(args, "O!O!i:gtk_html_end",
			  &PyGtk_Type, &html,
			  &PyCObject_Type, &handle,
			  &status))
	return NULL;

    stream = (GtkHTMLStreamHandle) PyCObject_AsVoidPtr (handle);
    gtk_html_end (GTK_HTML (PyGtk_Get(html)), stream, status);
    
    Py_INCREF(Py_None);
    return Py_None;
}

static PyMethodDef gtkhtmlMethods[] = {
    { "gtk_html_begin", _wrap_gtk_html_begin, 1 },
    { "gtk_html_write", _wrap_gtk_html_write, 1 },
    { "gtk_html_end", _wrap_gtk_html_end, 1 },
#include "gtkhtml_defs.c"
    { NULL, NULL, 0 }
};

void init_gtkhtml(void) {
    PyObject *m, *d;

    m = Py_InitModule("_gtkhtml", gtkhtmlMethods);
    
    init_pygtk();
    gdk_rgb_init();

    if (PyErr_Occurred())
	Py_FatalError("can't initialise module _gtkhtml");
}
